document.addEventListener('DOMContentLoaded', () => {
  const dropZone = document.getElementById('dropZone');
  const fileInput = document.getElementById('fileInput');
  const modelCards = document.querySelectorAll('.model-card');
  const previewSection = document.querySelector('.preview-section');

  // Drag and drop handlers
  dropZone.addEventListener('dragover', (e) => {
    e.preventDefault();
    dropZone.style.backgroundColor = '#f0f0ff';
  });

  dropZone.addEventListener('dragleave', (e) => {
    e.preventDefault();
    dropZone.style.backgroundColor = 'white';
  });

  dropZone.addEventListener('drop', (e) => {
    e.preventDefault();
    dropZone.style.backgroundColor = 'white';
    const files = e.dataTransfer.files;
    handleFiles(files);
  });

  dropZone.addEventListener('click', () => {
    fileInput.click();
  });

  fileInput.addEventListener('change', (e) => {
    handleFiles(e.target.files);
  });

  // Model selection
  modelCards.forEach(card => {
    card.addEventListener('click', () => {
      modelCards.forEach(c => c.classList.remove('selected'));
      card.classList.add('selected');
      if (fileInput.files.length > 0) {
        previewSection.hidden = false;
      }
    });
  });

  function handleFiles(files) {
    if (files.length === 0) return;
    
    const file = files[0];
    if (!file.name.endsWith('.nii') && !file.name.endsWith('.nii.gz')) {
      alert('Please upload a valid NIfTI file (.nii or .nii.gz)');
      return;
    }

    // Show preview section if model is selected
    if (document.querySelector('.model-card.selected')) {
      previewSection.hidden = false;
    }

    // Simulate processing
    const loadingMessage = document.createElement('div');
    loadingMessage.textContent = 'Processing...';
    loadingMessage.style.color = var(--primary);
    dropZone.appendChild(loadingMessage);

    setTimeout(() => {
      loadingMessage.remove();
      alert('File processed successfully! (Demo purposes only)');
    }, 2000);
  }
});
